# VOR
[![CodeQL](https://github.com/VOR-Lang/vor/actions/workflows/github-code-scanning/codeql/badge.svg)](https://github.com/VOR-Lang/vor/actions/workflows/github-code-scanning/codeql)

VOR Programming Language: VHD (Very High Definition) Omnidirectional Range Programming Language

(For the non-coders, this basically means this is a general purpose programming language)

## Table of Contents
- [VOR](#vor)
  - [Features](#features)
  - [Standard Libraries](#standard-libraries)

## Features

1. ***Importing Python Modules:*** VOR allows you to create modules in python which you can import into your script!
2. ***Custom Functions:*** VOR has built-in `debug()` and other functions to allow less code for you to write.

## Standard Libraries

- [system](https://github.com/Vor-Lang/system-lib)
